Customization class

Params that relate to the camera view controller customization and etc.

Constructors

Customization()

Properties

colors ↔ CustomizationColors
getter/setter pair
fonts ↔ CustomizationFonts
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
images ↔ CustomizationImages
getter/setter pair
onCustomButtonTapped ← CustomButtonTappedCompletion
Set onClick listener for buttons from uiCustomizationLayer.
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testSetters ↔ Map<String, dynamic>
getter/setter pair
uiCustomizationLayer ↔ Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → Customization
Allows you to deserialize object.