CustomizationColors class

Constructors

CustomizationColors()

Properties

cameraScreenBackHintLabelBackground ← Color
no getter
cameraScreenBackHintLabelText ← Color
no getter
cameraScreenDarkToolbarTint ← Color
no getter
cameraScreenFrontHintLabelBackground ← Color
no getter
cameraScreenFrontHintLabelText ← Color
no getter
cameraScreenLightToolbarTint ← Color
no getter
cameraScreenSectorActive ← Color
no getter
cameraScreenSectorTarget ← Color
no getter
cameraScreenStrokeActive ← Color
no getter
cameraScreenStrokeNormal ← Color
no getter
hashCode → int
The hash code for this object.
no setterinherited
onboardingScreenBackground ← Color
no getter
onboardingScreenMessageLabelsText ← Color
no getter
onboardingScreenStartButtonBackground ← Color
no getter
onboardingScreenStartButtonTitle ← Color
no getter
onboardingScreenSubtitleLabelText ← Color
no getter
onboardingScreenTitleLabelText ← Color
no getter
processingScreenBackground ← Color
no getter
processingScreenProgress ← Color
no getter
processingScreenTitleLabel ← Color
no getter
retryScreenBackground ← Color
no getter
retryScreenHintLabelsText ← Color
no getter
retryScreenRetryButtonBackground ← Color
no getter
retryScreenRetryButtonTitle ← Color
no getter
retryScreenSubtitleLabelText ← Color
no getter
retryScreenTitleLabelText ← Color
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successScreenBackground ← Color
no getter
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CustomizationColors
Allows you to deserialize object.