CustomizationFonts class

Constructors

CustomizationFonts()

Properties

cameraScreenHintLabel ← Font?
no getter
hashCode → int
The hash code for this object.
no setterinherited
onboardingScreenMessageLabels ← Font?
no getter
onboardingScreenStartButton ← Font?
no getter
onboardingScreenSubtitleLabel ← Font?
no getter
onboardingScreenTitleLabel ← Font?
no getter
processingScreenLabel ← Font?
no getter
retryScreenHintLabels ← Font?
no getter
retryScreenRetryButton ← Font?
no getter
retryScreenSubtitleLabel ← Font?
no getter
retryScreenTitleLabel ← Font?
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CustomizationFonts
Allows you to deserialize object.