CustomizationImages class

Constructors

CustomizationImages()

Properties

cameraScreenCloseButton ← ByteData
no getter
cameraScreenLightOffButton ← ByteData
no getter
cameraScreenLightOnButton ← ByteData
no getter
cameraScreenSwitchButton ← ByteData
no getter
hashCode → int
The hash code for this object.
no setterinherited
onboardingScreenAccessories ← ByteData
no getter
onboardingScreenCameraLevel ← ByteData
no getter
onboardingScreenCloseButton ← ByteData
no getter
onboardingScreenIllumination ← ByteData
no getter
processingScreenCloseButton ← ByteData
no getter
retryScreenCloseButton ← ByteData
no getter
retryScreenHintEnvironment ← ByteData
no getter
retryScreenHintSubject ← ByteData
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successScreenImage ← ByteData
no getter
testSetters ↔ Map<String, dynamic>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Allows you to serialize object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → CustomizationImages
Allows you to deserialize object.