DetectFaceResult class

Properties

attributes → List<DetectFacesAttributeResult>?
no setter
crop → Uint8List?
no setter
faceRect → Rect?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isQualityCompliant → bool
no setter
landmarks → List<Point>?
no setter
originalRect → Rect?
no setter
quality → List<ImageQualityResult>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DetectFaceResult?