InitConfig class

A configuration file for FaceSDK initialization. Allows to initialize using license binary. Also controls initialization time properties such as licenseUpdate.

Constructors

InitConfig(ByteData license, {bool? licenseUpdate})

Properties

hashCode → int
The hash code for this object.
no setterinherited
license → ByteData
The license binary file.
no setter
licenseUpdate → bool?
Enables automatic license update check during FaceSDK initialization.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → InitConfig?