LivenessResponse class

Properties

error → LivenessException?
no setter
estimatedAge → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → Uint8List?
no setter
liveness → LivenessStatus
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
no setter
transactionId → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → LivenessResponse?