MatchFacesDetectionFace class

Properties

crop → Uint8List?
no setter
faceIndex → int
no setter
faceRect → Rect
no setter
hashCode → int
The hash code for this object.
no setterinherited
landmarks → List<Point>
no setter
originalRect → Rect?
no setter
rotationAngle → double?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesDetectionFace?