MatchFacesImage class

Constructors

MatchFacesImage(Uint8List image, ImageType imageType, {bool? detectAll})

Properties

detectAll → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
no setter
image → Uint8List
no setter
imageType → ImageType
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesImage?