MatchFacesRequest class

Constructors

MatchFacesRequest(List<MatchFacesImage> images, {OutputImageParams? outputImageParams, String? tag, Map<String, dynamic>? metadata})

Properties

hashCode → int
The hash code for this object.
no setterinherited
images → List<MatchFacesImage>
no setter
metadata → Map<String, dynamic>?
no setter
outputImageParams → OutputImageParams?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesRequest?