MatchFacesResponse class

Properties

detections → List<MatchFacesDetection>
no setter
error → MatchFacesException?
no setter
hashCode → int
The hash code for this object.
no setterinherited
results → List<ComparedFacesPair>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesResponse?