PersonDatabase class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPersonImage(String personId, ImageUpload image) → Future<(PersonImage?, String?)>
createGroup(String name, {dynamic metadata}) → Future<(PersonGroup?, String?)>
createPerson(String name, {List<String> groupIds = const [], dynamic metadata}) → Future<(Person?, String?)>
deleteGroup(String groupId) → Future<(bool, String?)>
deletePerson(String personId) → Future<(bool, String?)>
deletePersonImage(String personId, String imageId) → Future<(bool, String?)>
editPersonsInGroup(String groupId, EditGroupPersonsRequest request) → Future<(bool, String?)>
getGroup(String groupId) → Future<(PersonGroup?, String?)>
getGroups() → Future<(PageableItemList<PersonGroup>, String?)>
getGroupsForPage(int page, int size) → Future<(PageableItemList<PersonGroup>, String?)>
getPerson(String personId) → Future<(Person?, String?)>
getPersonGroups(String personId) → Future<(PageableItemList<PersonGroup>, String?)>
getPersonGroupsForPage(String personId, int page, int size) → Future<(PageableItemList<PersonGroup>, String?)>
getPersonImage(String personId, String imageId) → Future<(PersonImage?, String?)>
getPersonImages(String personId) → Future<(PageableItemList<PersonImage>, String?)>
getPersonImagesForPage(String personId, int page, int size) → Future<(PageableItemList<PersonImage>, String?)>
getPersonsInGroup(String groupId) → Future<(PageableItemList<Person>, String?)>
getPersonsInGroupForPage(String groupId, int page, int size) → Future<(PageableItemList<Person>, String?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchPerson(SearchPersonRequest request) → Future<(SearchPerson, String?)>
toString() → String
A string representation of this object.
inherited
updateGroup(PersonGroup group) → Future<(bool, String?)>
updatePerson(Person person) → Future<(bool, String?)>

Operators

operator ==(Object other) → bool
The equality operator.
inherited