PersonImage class

Implementers

Properties

contentType → String
no setter
createdAt → DateTime
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
metadata → dynamic
no setter
path → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → PersonImage?