SearchPerson class

Inheritance

Properties

createdAt → DateTime
no setterinherited
detection → SearchPersonDetection?
no setter
groups → List<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
images → List<SearchPersonImage>
no setter
metadata ↔ dynamic
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SearchPerson
override